<?php
/*
 * Pinpoll Plugin File
 *
 * @link https://pinpoll.com
 * @since 3.0.0
 * @package Pinpoll
 *
 * Plugin Name: Pinpoll
 * Plugin URI: https://pinpoll.com
 * Text Domain: pinpoll
 * Domain Path: /lang
 * Description: Boost Engagement & Page Impressions!
 * Version: 3.0.5
 * Min WP Version: 3.3.0
 * Author: Pinpoll
 * Author URI: https://pinpoll.com
 * License: GPLv2 or later
 * License URI: http://www.gnu.org/licenses/gpl-2.0.html
 */

 //Security
 if ( ! defined( 'ABSPATH' ) ) { exit(); }

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
 die;
}

//INCLUDES config, texts
require_once( 'admin/config/pinpoll-config.php' );
require_once( 'admin/resources/pinpoll-texts.php' );

/**
 * Classname: Pinpoll
 * Description: Initiate the plugin, with all configurations
 *
 * @package Pinpoll
 *
 */
class Pinpoll {

    /**
     * construct where admin hooks are performed
     * which register settings, call menu structure, ...
     */
    public function __construct() {

      //hooks while loading plugin
      add_action( 'admin_init', array( $this, 'check_version' ) );
      // Don't run anything else in the plugin, if we're on an incompatible WordPress version
      if ( ! self::compatible_version() ) {
           return;
      }
      register_activation_hook( __FILE__, array( $this, 'pinpoll_on_activation' ) );
      add_action( 'admin_init', array( $this, 'pinpoll_settings' ) );
      add_action( 'admin_menu', array( $this, 'pinpoll_settings_menu' ) );
      add_action( 'admin_init', array( $this, 'init' ) );
      add_action( 'admin_enqueue_scripts', array( $this, 'load_styles' ) );
      add_shortcode( 'pinpoll', array( $this, 'pinpoll_shortcode_handler' ) );
      add_action( 'admin_init', array( $this, 'pinpoll_tinymce_button' ) );
      add_action( 'plugins_loaded', array( $this, 'pinpoll_load_translation' ) );
      add_action( 'admin_enqueue_scripts', array( $this, 'pinpoll_scripts' ) );

      //load localization vars to access in tinymce Editor
      foreach ( array('post.php','post-new.php') as $hook ) {
        add_action( "admin_head-$hook", array( $this, 'pinpoll_tinyMCE_translation' ) );
      }

    }

    // The primary sanity check, automatically disable the plugin on activation if it doesn't// meet minimum requirements.static
	function activation_check() {
		if ( ! self::compatible_version() ) {
			deactivate_plugins( plugin_basename( __FILE__ ) );
			wp_die( __( '<div class="wrap"><div class="error notice notice-error is-dismissible"> <p> Pinpoll requires WordPress 3.1 and PHP 5.5 or higher! </p> </div></div>', 'pinpoll' ) );
		}
	}

	// The backup sanity check, in case the plugin is activated in a weird way,
	// or the versions change after activation.
	function check_version() {
		if ( ! self::compatible_version() ) {
			if ( is_plugin_active( plugin_basename( __FILE__ ) ) ) {
				deactivate_plugins( plugin_basename( __FILE__ ) );
				add_action( 'admin_notices', array( $this, 'disabled_notice' ) );

				if ( isset( $_GET['activate'] ) ) {
					unset( $_GET['activate'] );
				}
			}
		}
	}

	function disabled_notice() {
		echo '<div class="wrap"><div class="error notice notice-error is-dismissible"><p>' . esc_html__( 'Pinpoll requires WordPress 3.1 and PHP 5.5 or higher!', 'pinpoll' ) . '</p> </div></div>';
	}

	static function compatible_version() {
	  if ( version_compare( PHP_VERSION, '5.5', '<' ) ) {
      return false;
    }
    if ( version_compare( $GLOBALS['wp_version'], '3.1', '<' ) ) {
			return false;
		}
		return true;
	}

    /**
     * Localization
     * Description: Load localization vars to ensure i18n in js files
     */
    function pinpoll_scripts() {
      $texts = pinpoll_get_switchaccount_texts();
      wp_enqueue_script( 'pinpoll-switch-account', plugin_dir_url( __FILE__ ) . 'admin/js/pinpoll_login_validate.js' );
      wp_localize_script( 'pinpoll-switch-account', 'ppTrans', array(
        'emailMessage' => $texts['emailmessage'],
        'passwordMessage'=> $texts['passwordmessage']
      ) );
    }

    /**
     * Localization TinyMCE
     * Description: Load localization vars in /tinymce/pinpoll_tinymce.js
     */
    function pinpoll_tinyMCE_translation() {
      $texts = pinpoll_get_tinymce_texts();

      ?>
      <script type="text/javascript">
        var ppTinyMCETrans = {
          'insertText' : '<?php printf( $texts['insert'] ); ?>',
          'quickInsertText' : '<?php printf( $texts['quickinsert'] ); ?>',
          'quickInsertLabel' : '<?php printf( $texts['quickinsertlabel'] ) ?>',
          'selectPollText' : '<?php printf( $texts['selectpoll'] ); ?>',
          'selectPollTitle' : '<?php printf( $texts['title'] ); ?>'
        }
      </script>
      <?php
    }

    /**
     * i18n
     * Description: Load translation files
     */
    function pinpoll_load_translation() {
      load_plugin_textdomain( 'pinpoll', false, dirname( plugin_basename( __FILE__ ) ) . '/lang/' );
    }

    /**
     * CSS
     * Description: Load css files
     */
    function load_styles() {
      wp_enqueue_style( 'pp-common-styles', plugins_url( '/css/pinpoll-common-style.css', __FILE__ ), false, '1.0.0' );
      wp_enqueue_style( 'pp-fontawesome', plugins_url( '/css/font-awesome.css', __FILE__ ), false, '1.0.0' );
      wp_enqueue_style( 'pp-sweetalert', plugins_url( '/css/sweetalert2.min.css', __FILE__ ), false, '1.0.0' );
    }

    /**
     * Register Settings
     * Description: Register Pinpoll plugin in admin menu
     */
    function pinpoll_settings() {
      register_setting('pinpoll_settings', 'pinpoll_account');
    }

    /**
     * Register Settings Menu
     * Description: Adds menu navigation to the wordpress sidebar
     */
    function pinpoll_settings_menu() {

      $texts = pinpoll_get_menuslug_texts();

      add_menu_page(
        $texts['title'], //Page Title
        $texts['title'], //Menu Title
        '2', // User role level
        'dashboard', // Menu slug
        array($this, 'pinpoll_dashboard'), //Callback funtion
        plugins_url( PINPOLL_ICON_URL ), //Icon
        '25.000000000000000002' //Menu position
      );

     add_submenu_page(
        'dashboard', //Super menu slug
        $texts['dashboard'], //Page Title
        $texts['dashboard'], //Menu Title
        '2', //User role
        'dashboard', //Menu slug
        array($this, 'pinpoll_dashboard') //Callback function
     );

     add_submenu_page(
        'dashboard',
        $texts['polls'],
        $texts['polls'],
        '2',
        'allpolls',
        array($this, 'pinpoll_list_all_polls')
      );

      add_submenu_page(
        'dashboard',
        $texts['create'],
        $texts['create'],
        '2',
        'createpoll',
        array($this, 'pinpoll_create_poll')
      );

      add_submenu_page(
        null,
        '',
        '',
        '2',
        'switchaccount',
        array($this, 'pinpoll_switch_account')
      );

      add_submenu_page(
        'dashboard',
        $texts['settings'],
        $texts['settings'],
        '2',
        'settings',
        array($this, 'pinpoll_account_status')
      );
    }

    /**
     * Dashboard Page
     * Description: If user clicks on "Dashboard" in admin menu,
     *              pinpoll-dashboard.php file will be shown.
     */
    function pinpoll_dashboard() {
      require_once('admin/pinpoll-dashboard.php');
    }

   /**
    * Account Status Page
    * Description: If user clicks on "Dashboard" in admin menu,
    *              pinpoll-account-status.php file will be shown.
    */
    function pinpoll_account_status() {
      require_once('admin/pinpoll-account-status.php');

    }

   /**
    * Polls Page
    * Description: If user clicks on "Dashboard" in admin menu,
    *              pinpoll-list-polls.php file will be shown.
    */
    function pinpoll_list_all_polls() {
      require_once('admin/pinpoll-all-polls.php');
    }

   /**
    * Create Poll Page
    * Description: If user clicks on "Dashboard" in admin menu,
    *              pinpoll-create-poll.php file will be shown.
    */
    function pinpoll_create_poll() {
      require_once('admin/pinpoll-create-poll.php');
    }

   /**
    * Switch Account Page
    * Description: If user clicks on "Dashboard" in admin menu,
    *              pinpoll-switch-account.php file will be shown.
    */
    function pinpoll_switch_account() {
      require_once('admin/pinpoll-switch-account.php');
    }

    /**
     * Helper Method Activation
     * Description: Add option to wp_options which helps to determine if the
     *              plugin is activated the first time.
     */
    function pinpoll_on_activation() {
      self::activation_check();
      add_option('pinpoll_plugin_on_activation', 'yes');
      add_option('pinpoll_account', array(
        'email' => '',
        'appkey' => ''
      ));
      add_option('pinpoll_jwt', '');
      add_option('pinpoll_feedback', array(
        'date' => '',
        'pollCreated' => ''
      ));
    }

    /**
     * Redirect to Pinpoll Settings
     * Desription: Redirects to the plugin page
     *             if pinpoll plugin is activated the first time
     */
    function init() {
      if(get_option('pinpoll_plugin_on_activation') == 'yes') {
        //$this->init_db(); no longer needed
        update_option('pinpoll_plugin_on_activation', 'no');
        wp_redirect(PINPOLL_SETTINGS_URL);
      }
    }

    /**
     * Shortcode Handling
     * Description: Handle shortcode [pinpoll] in posts and pages.
     *              Html code will be generated instead of the tag.
     *
     * @param  array $atts attributes of tag pinpoll
     * @return html        poll
     */
    function pinpoll_shortcode_handler( $atts, $content = null ) {
      if (!empty($atts)) {
        $a = shortcode_atts(array(
            'id' => '404'
          ), $atts
        );
        $id = $a['id'];
      }else if (!empty($content)) {
        $matches = array();
        preg_match('/\/embed\/(\d+)/', $content, $matches);
        $id = $matches[1];
      }
      ob_start();
      ?>
       <script data-id="<?php printf( $id ); ?>" data-location="<?php printf( PINPOLL_JS_URL ); ?>">!function(){var a="pinpoll: couldn't locate currentScript",b=function(){if(document.currentScript)return document.currentScript;var a=document.getElementsByTagName("script"),b=a[a.length-1];if(!b.getAttribute("data-id")){b=null,String.prototype.startsWith||(String.prototype.startsWith=function(a,b){return b=b||0,this.substr(b,a.length)===a});for(var c=0;c<a.length;c++)if(a[c].getAttribute("data-pinpoll-id")||a[c].getAttribute("data-id")&&a[c].innerText.startsWith('!function(){var a = "pinpoll')){b=a[c];break}}return b}();if(!b)return void console.log(a);if(window.Pinpoll)window.Pinpoll.init(b);else{var c=document.querySelectorAll('script[src="<?php printf( PINPOLL_JS_URL ); ?>/global.js?v=<?php printf( PINPOLL_JS_VERSION ); ?>"]')[0];c||(c=document.createElement("script"),c.src="<?php printf( PINPOLL_JS_URL ); ?>/global.js?v=<?php printf( PINPOLL_JS_VERSION ); ?>",c.async=!0,document.head.appendChild(c));var d=c.onload;c.onload=function(){window.Pinpoll.init(b),d&&d()}}}();</script>
     </div>
      <?php
      return ob_get_clean();
    }

    /**
     * Init TinyMCE Buttons
     * Description: Add TinyMCE buttons in editor if user can edit_posts
     *              and pages
     */
    function pinpoll_tinymce_button() {
      if( current_user_can( 'edit_posts' ) && current_user_can( 'edit_pages' ) ) {
        add_filter('mce_buttons', array($this, 'pinpoll_register_tinymce_button'));
        add_filter('mce_external_plugins', array($this, 'pinpoll_add_tinymce_button'));
      }
    }

    /**
     * Register TinyMCE Buttons
     * Description: Add TinyMCE Buttons in the button array of wordpress editor
     *
     * @param  array  $buttons  tinymce buttons
     * @return array  $buttons  tinymce buttons included pinpoll
     */
    function pinpoll_register_tinymce_button( $buttons ) {
      array_push( $buttons, 'pinpollButton');
      return $buttons;
    }

    /**
     * Add TinyMCE Buttons
     * Description: Adding pinpoll-tinymce.js file, that js file is registered
     *
     * @param   array   $plugin_array   plugin array
     * @return  array   $plugin_array   plugin_array
     */
    function pinpoll_add_tinymce_button( $plugin_array ) {
      $plugin_array['pinpoll_button_script'] = plugins_url( '/tinymce/pinpoll_tinymce.js', __FILE__ );
      return $plugin_array;
    }
}

$Pinpoll = new Pinpoll();
?>
